@@ -242,13 +242,13 @@ extern "C"
 
     void GetWechslerOfPattern(void* pat, char* buffer) {
         auto ppat = reinterpret_cast<apg::pattern*>(pat);
-        std::string s = ppat->phase_wechsler();
+        std::string s = ppat->phase_wechsler(999999999);
         s.copy(buffer, 2048);
     }
 
     void GetApgcodeOfPattern(void* pat, char* buffer) {
         auto ppat = reinterpret_cast<apg::pattern*>(pat);
-        std::string s = ppat->apgcode();
+        std::string s = ppat->apgcode(999999999, 999999999);
         s.copy(buffer, 2048);
     }
 
