@@ -25,6 +25,23 @@ class Lifetree(object):
 
         session.lifetree_ptrs.add(self.ptr)
 
+    def unify(self, *patterns):
+
+        output = self.pattern()
+
+        for (i, pat) in enumerate(patterns):
+
+            this_layer = self.pattern()
+            this_layer += pat
+            output += (this_layer << i)
+
+        return output
+
+    def deunify(self, pattern):
+
+        n = self.n_layers
+        return tuple([((pattern << (n - 1 - i)) >> (n - 1)) for i in range(n)])
+
     def load(self, filename, compressed='deduce', tempfile='tempfile'):
 
         filename = os.path.abspath(filename)
