@@ -212,6 +212,23 @@ $.4B$4B$3B$2B!'''
         actual_apgcode = self.make_p51()[27].apgcode
         self.assertEqual(actual_apgcode, desired_apgcode)
 
+    def test_large_apgcode(self):
+
+        cordership = self.lt.pattern('''x = 113, y = 114, rule = B3/S23
+79bo$78bobo$77b2ob2o$78bo2bo$80b3o$80bobo$81b2o$81b2o12b2o$95b2o3$79bo$78bobo
+$78bobo$79bo$103b2o$103b2o3$87bo$86bobo$86bobo$65bobo19bo$64b2ob2o27bo14b2o$
+65bob2o27b3o12b2o$69bo25b2o2bo$68bo28bo2bo$50bo17bo25bobo2bo$50bo44b3o$50bo8b
+o37bo$57bobo35bobo$51b3o2bo3bo34b2o7bo$52bob5o45b2o$58bo44bobo$53b2o4$32b3o$
+32bobo$32b3o19b2o$48bo5bo$46bobo3bo2bo$34b2o10bo3bo3bo$32b2ob2o10b7o$32b2o2b
+2o$31b2o3b2o14bo$32b2o2b2o12bobo19bo$33bobo13bo2bo19b2o$50b2o19bobo3$25bo$25b
+o28b2o$25bo8bo19b2o$32bobo9b2o16b2ob3o$26b3o2bo3bo8b2o18bo$27bob5o31bo3bo$33b
+o32b2obo$28b2o37bo2bo$68b2o3$52b2o$52b2o4$36bo$35b4o$33b5obo$32bo6b2o$31bo3bo
+b3o$25bo6bobo2b2o$13bobo7bob2o$12b2ob2o6bobo$13bob2o6b2o$2bo14bo$bobo12bo$2ob
+2o11bo$bo2bo$3b3o$3bobo$4b2o$4b2o3$11b2o$2bo7bo2bo$3bo7b2o$3b2o$2b3o$36bo$34b
+2o$3b3o29b2o$bo4bo12b2o$b2o3bo11bo2bo$3b4o12b2o7$6b2o$6b2o7$14b2o$14b2o!''')
+        long_apgcode = cordership.apgcode
+        self.assertEqual(len(long_apgcode), 323)
+
     def test_p51(self):
 
         p51 = self.make_p51()
